@@ -323,11 +323,23 @@ def filter_countries(df, countries,fixed_filter):
 
     return df
 
+def change_bulkstatus_to_string(df):
+    if 'BulkStatus' in df:
+        df.loc[(df['BulkStatus'] == 2), 'BulkStatus'] = 'FU'
+        df.loc[(df['BulkStatus'] == 0), 'BulkStatus'] = 'New'
+        df.loc[(df['BulkStatus'] == 6), 'BulkStatus'] = 'OOO'
+        df.loc[(df['BulkStatus'] == 12), 'BulkStatus'] = 'NN'
+        df.loc[~(df['BulkStatus'] in (2,0,6,12), 'BulkStatus'] = 'Other'
+    return df
+
 def impute_growth(df,impute_growth_flag):
     if impute_growth_flag==1:
+        logger.info("Applying growth imputation")
         df['Growth12M']=df['Growth12M'].fillna(df['Growth6M'])
         df['Growth6M']=df['Growth6M'].fillna(df['Growth3M'])
         df['Growth3M']=df['Growth3M'].fillna(df['Growth6M'])
+    else:
+        logger.info("not applying growth imputation")
     return df
     
 
